@@ -398,7 +398,7 @@ _vte_pango_draw_rectangle(struct _vte_draw *draw,
 	gdk_gc_set_foreground(data->gc, &wcolor);
 
 	gdk_draw_rectangle(draw->widget->window, data->gc, FALSE,
-			   x, y, width, height);
+			   x, y, width-1, height-1);
 }
 
 static void
@@ -426,7 +426,7 @@ _vte_pango_set_scroll(struct _vte_draw *draw, gint x, gint y)
 }
 
 const struct _vte_draw_impl _vte_draw_pango = {
-	"Pango",
+	"pango",
 	_vte_pango_check,
 	_vte_pango_create,
 	_vte_pango_destroy,
